@@ -53,7 +53,7 @@ static QString getWriterName(AVThread *avThr)
 
 static QString getCoverFile(const QString &title, const QString &artist, const QString &album)
 {
-    return QMPlay2Core.getSettingsDir() + "Covers/" + QCryptographicHash::hash((album.isEmpty() ? title.toUtf8() : album.toUtf8()) + artist.toUtf8(), QCryptographicHash::Md5).toHex();
+    return QMPlay2Core.getSettingsDir() + "Covers/" + QCryptographicHash::hash(QByteArray((album.isEmpty() ? title.toUtf8() : album.toUtf8()) + artist.toUtf8()), QCryptographicHash::Md5).toHex();
 }
 
 class BufferInfo
@@ -1117,12 +1117,12 @@ void DemuxerThr::emitInfo()
                 audioStreams += "<li><b>" + tr("sample rate") + ":</b> " + QString::number(streamInfo->params->sample_rate) + " Hz</li>";
 
                 QString channels;
-                if (streamInfo->params->channels == 1)
+                if (streamInfo->params->CODECPAR_NB_CHANNELS == 1)
                     channels = tr("mono");
-                else if (streamInfo->params->channels == 2)
+                else if (streamInfo->params->CODECPAR_NB_CHANNELS == 2)
                     channels = tr("stereo");
                 else
-                    channels = QString::number(streamInfo->params->channels);
+                    channels = QString::number(streamInfo->params->CODECPAR_NB_CHANNELS);
                 audioStreams += "<li><b>" + tr("channels") + ":</b> " + channels + "</li>";
 
                 if (!bitrateStr.isEmpty())
@@ -1312,21 +1312,27 @@ void DemuxerThr::stopVADec()
     playC.stopVDec();
     playC.stopADec();
 
-    const QString key = "UrlPos/" + playC.getUrl();
-    auto &settings = QMPlay2Core.getSettings();
+    const QString key = playC.getUrl().toUtf8().toBase64(QByteArray::Base64UrlEncoding | QByteArray::OmitTrailingEquals);
     const double pos = playC.getPos();
-    bool store = !err && !unknownLength && demuxer && settings.getBool("StoreUrlPos");
+    bool store = !err && !unknownLength && demuxer && QMPlay2Core.getSettings().getBool("StoreUrlPos");
     if (store)
     {
         const double length = demuxer->length();
         const double percent = pos * 100.0 / length;
         if (length < 480.0 || percent < 1.0 || percent > 99.0)
-            store = false;
+        {
+            if (!playC.dontResetContinuePlayback)
+                QMPlay2Core.getUrlPosSets().remove(key);
+        }
+        else
+        {
+            QMPlay2Core.getUrlPosSets().set(key, pos);
+        }
     }
-    if (store)
-        settings.set(key, pos);
     else
-        settings.remove(key);
+    {
+        QMPlay2Core.getUrlPosSets().remove(key);
+    }
 
     stopVAMutex.unlock();
 
