@@ -36,11 +36,12 @@
 #ifdef Q_OS_MACOS
     #include <QProcess>
 #endif
-#if defined(Q_OS_WIN) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    #include <QWinThumbnailToolButton>
-    #include <QWinThumbnailToolBar>
-    #include <QWinTaskbarProgress>
-    #include <QWinTaskbarButton>
+#if defined(Q_OS_WIN)
+    #include <QOperatingSystemVersion>
+    #include <QtWinExtras/qwinthumbnailtoolbutton.h>
+    #include <QtWinExtras/qwinthumbnailtoolbar.h>
+    #include <QtWinExtras/qwintaskbarprogress.h>
+    #include <QtWinExtras/qwintaskbarbutton.h>
 #endif
 #if defined(Q_OS_WIN) && QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
     #include <dwmapi.h>
@@ -157,7 +158,7 @@ MainWidget::MainWidget(QList<QPair<QString, QString>> &arguments)
     isCompactView = wasShow = fullScreen = seekSFocus = false;
 
     if (QMPlay2GUI.pipe)
-        connect(QMPlay2GUI.pipe, SIGNAL(newConnection(IPCSocket *)), this, SLOT(newConnection(IPCSocket *)));
+        connect(QMPlay2GUI.pipe.get(), SIGNAL(newConnection(IPCSocket *)), this, SLOT(newConnection(IPCSocket *)));
 
     Settings &settings = QMPlay2Core.getSettings();
 
@@ -271,6 +272,8 @@ MainWidget::MainWidget(QList<QPair<QString, QString>> &arguments)
     mainTB->addAction(menuBar->player->next);
     mainTB->addAction(menuBar->window->toggleFullScreen);
 
+    mainTB->addAction(menuBar->player->continuePlayback);
+
     seekS = new Slider;
     seekS->setMaximum(0);
     seekS->setWheelStep(settings.getInt("ShortSeek"));
@@ -282,8 +285,6 @@ MainWidget::MainWidget(QList<QPair<QString, QString>> &arguments)
     vLine->setFrameShadow(QFrame::Sunken);
     mainTB->addWidget(vLine);
 
-    mainTB->addAction(menuBar->player->continuePlayback);
-
     mainTB->addAction(menuBar->player->toggleMute);
 
     volW = new VolWidget(settings.getInt("MaxVol"));
@@ -357,9 +358,12 @@ MainWidget::MainWidget(QList<QPair<QString, QString>> &arguments)
         menuBar->playback->videoFilters->vFlip->setChecked(vFlip);
         menuBar->playback->videoFilters->spherical->setChecked(spherical);
     });
-    connect(&playC, &PlayClass::continuePos, this, [this](double pos) {
+    connect(&playC, &PlayClass::continuePos, this, [this](double pos, bool canSetVar) {
+        const bool enabled = (pos > 0.0);
         menuBar->player->continuePlayback->setProperty("Pos", pos);
-        menuBar->player->continuePlayback->setVisible(pos > 0.0);
+        menuBar->player->continuePlayback->setEnabled(enabled);
+        if (canSetVar)
+            playC.setDontResetContinuePlayback(enabled);
     });
     /**/
 
@@ -466,10 +470,13 @@ MainWidget::MainWidget(QList<QPair<QString, QString>> &arguments)
         {
             playC.setDoSilenceOnStart();
             playlistDock->start();
-            if (!settings.getBool("StoreUrlPos"))
+            const double pos = settings.getDouble("Pos", 0.0);
+            if (pos > 0.0)
             {
-                const double pos = settings.getDouble("Pos", 0.0);
-                if (pos > 0.0)
+                double urlPos = 0.0;
+                if (settings.getBool("StoreUrlPos"))
+                    urlPos = QMPlay2Core.getUrlPosSets().getDouble(url.toUtf8().toBase64(QByteArray::Base64UrlEncoding | QByteArray::OmitTrailingEquals));
+                if (urlPos <= 0.0 || abs(urlPos - pos) <= 0.75)
                     seek(pos);
             }
         }
@@ -574,10 +581,13 @@ void MainWidget::processParam(const QString &param, const QString &data)
     else if (param == "show")
     {
         if (!isVisible())
-            toggleVisibility();
-        if (isMinimized())
         {
-            showNormal();
+            toggleVisibility();
+        }
+        else
+        {
+            if (isMinimized())
+                showNormal();
             activateWindow();
             raise();
         }
@@ -679,7 +689,7 @@ void MainWidget::playStateChanged(bool b)
         menuBar->player->togglePlay->setIcon(QMPlay2Core.getIconFromTheme("media-playback-start"));
         menuBar->player->togglePlay->setText(tr("&Play"));
     }
-#if defined(Q_OS_WIN) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if defined(Q_OS_WIN)
     if (m_taskBarProgress)
         m_taskBarProgress->setPaused(!b);
 #endif
@@ -941,7 +951,7 @@ void MainWidget::createMenuBar()
         if (pos > 0.0)
             playC.seek(pos);
         else
-            emit playC.continuePos(0.0);
+            emit playC.continuePos(0.0, true);
     });
     connect(menuBar->player->volUp, SIGNAL(triggered()), this, SLOT(volUpDown()));
     connect(menuBar->player->volDown, SIGNAL(triggered()), this, SLOT(volUpDown()));
@@ -998,6 +1008,8 @@ void MainWidget::createMenuBar()
     else
         menuBar->options->trayVisible->setVisible(false);
 
+    setContinuePlaybackVisibility();
+
     setMenuBar(menuBar);
 
 #ifndef Q_OS_MACOS
@@ -1377,6 +1389,12 @@ void MainWidget::showSettings(const QString &moduleName)
         if (windowFlags() & Qt::WindowStaysOnTopHint)
             settingsW->setWindowFlag(Qt::WindowStaysOnTopHint);
         settingsW->show();
+        connect(settingsW, &SettingsWidget::settingsChanged, this, [this](int page, bool forceRestart, bool initFilters) {
+            Q_UNUSED(forceRestart);
+            Q_UNUSED(initFilters);
+            if (page == 2)
+                setContinuePlaybackVisibility();
+        });
         connect(settingsW, SIGNAL(settingsChanged(int, bool, bool)), &playC, SLOT(settingsChanged(int, bool, bool)));
         connect(settingsW, SIGNAL(setWheelStep(int)), seekS, SLOT(setWheelStep(int)));
         connect(settingsW, SIGNAL(setVolMax(int)), volW, SLOT(setMaximumVolume(int)));
@@ -1425,7 +1443,7 @@ void MainWidget::browseSubsFile()
 void MainWidget::setSeekSMaximum(int max)
 {
     seekS->setMaximum(qMax(0, max * 10));
-#if defined(Q_OS_WIN) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if defined(Q_OS_WIN)
     if (m_taskBarProgress)
     {
         m_taskBarProgress->setMaximum(seekS->maximum() / 10);
@@ -1462,7 +1480,7 @@ void MainWidget::updatePos(double pos)
             currPos = intPos;
         }
         seekS->setValue(pos * 10.0);
-#if defined(Q_OS_WIN) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if defined(Q_OS_WIN)
         if (m_taskBarProgress)
             m_taskBarProgress->setValue(pos);
 #endif
@@ -1742,10 +1760,15 @@ void MainWidget::addChooseNextStreamKeyShortcuts()
     QMPlay2GUI.shortcutHandler->appendAction(nextSubsStream, "KeyBindings/NextSubsStream", "Ctrl+2");
 }
 
-#if defined(Q_OS_WIN) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+void MainWidget::setContinuePlaybackVisibility()
+{
+    menuBar->player->continuePlayback->setVisible(QMPlay2Core.getSettings().getBool("StoreUrlPos"));
+}
+
+#if defined(Q_OS_WIN)
 void MainWidget::setWindowsTaskBarFeatures()
 {
-    if (QSysInfo::windowsVersion() < QSysInfo::WV_6_1)
+    if (QOperatingSystemVersion::current() < QOperatingSystemVersion::Windows7)
         return;
 
     m_taskbarButton = new QWinTaskbarButton(this);
@@ -1985,7 +2008,7 @@ void MainWidget::closeEvent(QCloseEvent *e)
     emit QMPlay2Core.waitCursor();
 
     if (QMPlay2GUI.pipe)
-        disconnect(QMPlay2GUI.pipe, SIGNAL(newConnection(IPCSocket *)), this, SLOT(newConnection(IPCSocket *)));
+        disconnect(QMPlay2GUI.pipe.get(), SIGNAL(newConnection(IPCSocket *)), this, SLOT(newConnection(IPCSocket *)));
 
     if (wasShow)
     {
@@ -2037,7 +2060,7 @@ void MainWidget::closeEvent(QCloseEvent *e)
 
     playC.stop(true);
 
-#if defined(Q_OS_WIN) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if defined(Q_OS_WIN)
     m_taskBarProgress = nullptr;
     delete m_taskbarButton;
     delete m_thumbnailToolBar;
@@ -2060,7 +2083,7 @@ void MainWidget::showEvent(QShowEvent *)
 #endif
             showMaximized();
         doRestoreState(QMPlay2Core.getSettings().getByteArray("MainWidget/DockWidgetState"), QMPlay2Core.getSettings().getBool("MainWidget/IsCompactView"));
-#if defined(Q_OS_WIN) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if defined(Q_OS_WIN)
         setWindowsTaskBarFeatures();
 #endif
 #if defined(Q_OS_WIN) && QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
