@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2023  Błażej Szczygieł
+    Copyright (C) 2010-2024  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -38,7 +38,7 @@ class PlaylistDock;
 class SettingsWidget;
 class QMPlay2Extensions;
 
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN)
     class QWinTaskbarProgress;
     class QWinTaskbarButton;
     class QWinThumbnailToolBar;
@@ -118,7 +118,7 @@ private slots:
     void lockWidgets(bool);
 
     void hideDocksSlot();
-    void doRestoreState(const QByteArray &data);
+    void doRestoreState(const QByteArray &data, bool doToggleCompactView = false);
 
     void uncheckSuspend();
 private:
@@ -137,9 +137,14 @@ private:
 
     void addChooseNextStreamKeyShortcuts();
 
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN)
     void setWindowsTaskBarFeatures();
 #endif
+#if defined(Q_OS_WIN) && QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+    void setTitleBarStyle();
+#endif
+
+    void setContinuePlaybackVisibility();
 
     void keyPressEvent(QKeyEvent *) override;
     void mouseMoveEvent(QMouseEvent *) override;
@@ -198,7 +203,7 @@ private:
     Updater updater;
 #endif
 
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN)
     QWinTaskbarProgress *m_taskBarProgress = nullptr;
     QWinTaskbarButton *m_taskbarButton = nullptr;
     QWinThumbnailToolBar *m_thumbnailToolBar = nullptr;
