@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2020  Błażej Szczygieł
+    Copyright (C) 2010-2024  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -43,54 +43,9 @@
 
 #include <cmath>
 
-#if defined Q_OS_WIN && !defined Q_OS_WIN64
-    #include <QProgressBar>
-    #include <QVBoxLayout>
-    #include <QLabel>
-
-    class UpdateFC : public QThread
-    {
-    public:
-        UpdateFC(LibASS *ass) :
-            ass(ass)
-        {
-            start();
-            if (!wait(500))
-            {
-                QDialog d(QMPlay2GUI.mainW);
-                d.setWindowTitle(QCoreApplication::applicationName());
-                QLabel l(QObject::tr("Font cache is being updated, please wait"));
-                QProgressBar p;
-                p.setRange(0, 0);
-                QVBoxLayout la(&d);
-                la.addWidget(&l);
-                la.addWidget(&p);
-                d.open();
-                d.setMinimumSize(d.size());
-                d.setMaximumSize(d.size());
-                do
-                    el.processEvents(QEventLoop::ExcludeUserInputEvents | QEventLoop::WaitForMoreEvents);
-                while (isRunning());
-            }
-        }
-    private:
-        void run()
-        {
-            ass->initOSD();
-            SetFileAttributesW((WCHAR *)QString(QDir::homePath() + "/fontconfig").utf16(), FILE_ATTRIBUTE_HIDDEN);
-            el.wakeUp();
-        }
-        LibASS *ass;
-        QEventLoop el;
-    };
-#endif
-
 PlayClass::PlayClass() :
     demuxThr(nullptr), vThr(nullptr), aThr(nullptr),
     aRatioName("auto"),
-#if defined Q_OS_WIN && !defined Q_OS_WIN64
-    firsttimeUpdateCache(true),
-#endif
     ass(nullptr), osd(nullptr)
 {
     doSilenceBreak = doSilenceOnStart = false;
@@ -101,6 +56,8 @@ PlayClass::PlayClass() :
 
     quitApp = muted = reload = videoDecErrorLoad = false;
 
+    keepAudioPitch = QMPlay2Core.getSettings().getBool("KeepAudioPitch");
+
     if (QMPlay2Core.getSettings().getBool("StoreARatioAndZoom"))
     {
         zoom = qBound(0.05, QMPlay2Core.getSettings().getDouble("Zoom", 1.0), 100.0);
@@ -147,10 +104,12 @@ void PlayClass::play(const QString &_url)
         {
             audioStream = videoStream = subtitlesStream = -1;
 
+
             url = _url;
             demuxThr = new DemuxerThr(*this);
             demuxThr->minBuffSizeLocal = QMPlay2Core.getSettings().getInt("AVBufferLocal");
-            demuxThr->minBuffSizeNetwork = QMPlay2Core.getSettings().getInt("AVBufferNetwork");
+            demuxThr->m_minBuffTimeNetwork = QMPlay2Core.getSettings().getDouble("AVBufferTimeNetwork");
+            demuxThr->m_minBuffTimeNetworkLive = QMPlay2Core.getSettings().getDouble("AVBufferTimeNetworkLive");
             demuxThr->playIfBuffered = QMPlay2Core.getSettings().getDouble("PlayIfBuffered");
             demuxThr->updateBufferedSeconds = QMPlay2Core.getSettings().getBool("ShowBufferedTimeOnSlider");
 
@@ -209,6 +168,9 @@ void PlayClass::play(const QString &_url)
             paused = false;
 
             demuxThr->start();
+
+            if (QMPlay2Core.getSettings().getBool("StoreUrlPos"))
+                emit continuePos(QMPlay2Core.getUrlPosSets().getDouble(url.toUtf8().toBase64(QByteArray::Base64UrlEncoding | QByteArray::OmitTrailingEquals)), true);
         }
     }
     else
@@ -219,6 +181,7 @@ void PlayClass::play(const QString &_url)
 }
 void PlayClass::stop(bool _quitApp)
 {
+    emit continuePos(0.0, false);
     quitApp = _quitApp;
     if (stopPauseMutex.tryLock())
     {
@@ -286,6 +249,7 @@ void PlayClass::seek(double pos, bool allowAccurate)
         pos = 0.0;
     if (qFuzzyCompare(lastSeekTo, pos))
         return;
+    emit continuePos(0.0, true);
     allowAccurateSeek = allowAccurate;
     if ((seekA > -1.0 && pos < seekA) || (seekB > -1.0 && pos > seekB))
     {
@@ -311,14 +275,14 @@ void PlayClass::seek(double pos, bool allowAccurate)
 void PlayClass::chStream(const QString &s)
 {
     if (s.startsWith("audio"))
-        chosenAudioStream = s.rightRef(s.length() - 5).toInt();
+        chosenAudioStream = QStringView(s).right(s.length() - 5)MAYBE_TO_STRING.toInt();
     else if (s.startsWith("video"))
-        chosenVideoStream = s.rightRef(s.length() - 5).toInt();
+        chosenVideoStream = QStringView(s).right(s.length() - 5)MAYBE_TO_STRING.toInt();
     else if (s.startsWith("subtitles"))
-        chosenSubtitlesStream = s.rightRef(s.length() - 9).toInt();
+        chosenSubtitlesStream = QStringView(s).right(s.length() - 9)MAYBE_TO_STRING.toInt();
     else if (s.startsWith("fileSubs"))
     {
-        int idx = s.rightRef(s.length() - 8).toInt();
+        int idx = QStringView(s).right(s.length() - 8)MAYBE_TO_STRING.toInt();
         if (fileSubsList.count() > idx)
             loadSubsFile(fileSubsList[idx]);
     }
@@ -386,7 +350,6 @@ void PlayClass::loadSubsFile(const QString &fileName, const QList<StreamInfo *>
             if (!QMPlay2Core.getSettings().getBool("KeepSubtitlesDelay"))
                 subtitlesSync = 0.0;
             ass->closeASS();
-            ass->clearFonts();
 
             bool loaded = false;
             const QString fileExt = Functions::fileExt(fileName).toLower();
@@ -462,6 +425,16 @@ void PlayClass::messageAndOSD(const QString &txt, bool onStatusBar, double durat
         emit QMPlay2Core.statusBarMessage(txt, duration * 1000);
 }
 
+void PlayClass::setKeepAudioPitch(bool keep)
+{
+    keepAudioPitch = keep;
+    if (keepAudioPitch)
+        messageAndOSD(tr("Keep audio pitch during playback speed change"));
+    else
+        messageAndOSD(tr("Don't keep audio pitch during playback speed change"));
+    QMPlay2Core.getSettings().set("KeepAudioPitch", keepAudioPitch);
+}
+
 inline bool PlayClass::hasVideoStream()
 {
     return vThr && demuxThr && demuxThr->demuxer && videoStream > -1;
@@ -482,12 +455,15 @@ double PlayClass::getARatio()
     if (aRatioName == "auto")
         return demuxThr->demuxer->streamsInfo().at(videoStream)->getAspectRatio();
     if (aRatioName == "sizeDep")
-        return (double)demuxThr->demuxer->streamsInfo().at(videoStream)->width / (double)demuxThr->demuxer->streamsInfo().at(videoStream)->height;
+        return (double)demuxThr->demuxer->streamsInfo().at(videoStream)->params->width / (double)demuxThr->demuxer->streamsInfo().at(videoStream)->params->height;
     return aRatioName.toDouble();
 }
 inline AVRational PlayClass::getSAR()
 {
-    return demuxThr->demuxer->streamsInfo().at(videoStream)->sample_aspect_ratio;
+    const auto streamInfo = demuxThr->demuxer->streamsInfo().at(videoStream);
+    if (!streamInfo->custom_sar)
+        return streamInfo->params->sample_aspect_ratio;
+    return {};
 }
 
 void PlayClass::flushAssEvents()
@@ -597,7 +573,7 @@ void PlayClass::flipRotMsg()
         case Qt::Vertical:
             str = tr("Vertical flip");
             break;
-        case Qt::Horizontal + Qt::Vertical:
+        case Qt::Horizontal | Qt::Vertical:
             if (rotate90)
                 str = tr("Rotation 270°");
             else
@@ -650,8 +626,15 @@ bool PlayClass::setAudioParams(quint8 realChannels, quint32 realSampleRate)
     quint8 chn = 0;
     if (QMPlay2Core.getSettings().getBool("ForceSamplerate"))
         srate = QMPlay2Core.getSettings().getUInt("Samplerate");
-    if (QMPlay2Core.getSettings().getBool("ForceChannels"))
+    if (const auto forceChn = QMPlay2Core.getSettings().getInt("ForceChannels"))
+    {
         chn = QMPlay2Core.getSettings().getUInt("Channels");
+        if (forceChn == Qt::PartiallyChecked && chn < realChannels)
+        {
+            // only promote the effective channel count
+            chn = 0;
+        }
+    }
     return aThr->setParams(realChannels, realSampleRate, chn, srate, QMPlay2Core.getSettings().getBool("ResamplerFirst"));
 }
 
@@ -659,7 +642,7 @@ void PlayClass::loadAssFonts(const QList<StreamInfo *> &streams)
 {
     for (auto &&stream : streams)
     {
-        if (stream->codec_type == AVMEDIA_TYPE_ATTACHMENT && (stream->codec_name == "TTF" || stream->codec_name == "OTF") && stream->extradata_size > 0)
+        if (stream->params->codec_type == AVMEDIA_TYPE_ATTACHMENT && (stream->codec_name == "TTF" || stream->codec_name == "OTF") && stream->params->extradata_size > 0)
             ass->addFont(stream->title, stream->getExtraData());
     }
 }
@@ -805,7 +788,7 @@ void PlayClass::slowDown()
 void PlayClass::setSpeed()
 {
     bool ok;
-    double s = QInputDialog::getDouble(nullptr, tr("Play speed"), tr("Set playback speed (sec.)"), speed, 0.05, 100.0, 2, &ok);
+    double s = QInputDialog::getDouble(nullptr, tr("Play speed"), tr("Set playback speed"), speed, 0.05, 100.0, 3, &ok);
     if (ok)
     {
         speed = s;
@@ -1100,8 +1083,8 @@ void PlayClass::frameSizeUpdated(int w, int h) //jeżeli rozmiar obrazu zmieni s
     if (hasVideoStream())
     {
         StreamInfo *streamInfo = demuxThr->demuxer->streamsInfo().at(videoStream);
-        streamInfo->width = w;
-        streamInfo->height = h;
+        streamInfo->params->width = w;
+        streamInfo->params->height = h;
         const double aspect_ratio = getARatio();
         if (ass)
             ass->setARatio(aspect_ratio);
@@ -1120,7 +1103,7 @@ void PlayClass::aRatioUpdated(const AVRational &sar) //jeżeli współczynnik pr
 {
     if (hasVideoStream())
     {
-        demuxThr->demuxer->streamsInfo().at(videoStream)->sample_aspect_ratio = sar;
+        demuxThr->demuxer->streamsInfo().at(videoStream)->params->sample_aspect_ratio = sar;
         const double aspect_ratio = getARatio();
         if (ass)
             ass->setARatio(aspect_ratio);
@@ -1146,8 +1129,8 @@ void PlayClass::audioParamsUpdated(quint8 channels, quint32 sampleRate)
     if (hasAudioStream())
     {
         StreamInfo *streamInfo = demuxThr->demuxer->streamsInfo().at(audioStream);
-        streamInfo->sample_rate = sampleRate;
-        streamInfo->channels = channels;
+        streamInfo->params->sample_rate = sampleRate;
+        streamInfo->params->CODECPAR_NB_CHANNELS = channels;
         demuxThr->emitInfo();
     }
     if (aThr)
@@ -1277,7 +1260,7 @@ static Decoder *loadStream(
 
     Decoder *dec = nullptr;
     const bool subtitles = (type == AVMEDIA_TYPE_SUBTITLE);
-    if (chosenStream >= 0 && chosenStream < streams.count() && streams[chosenStream]->codec_type == type)
+    if (chosenStream >= 0 && chosenStream < streams.count() && streams[chosenStream]->params->codec_type == type)
     {
         if (streams[chosenStream]->must_decode || !subtitles)
             dec = Decoder::create(*streams[chosenStream], decoders, modNameOutput);
@@ -1289,13 +1272,13 @@ static Decoder *loadStream(
         int defaultStream = -1, chosenLangStream = -1;
         for (int i = 0; i < streams.count(); ++i)
         {
-            if (streams[i]->codec_type == type)
+            if (streams[i]->params->codec_type == type)
             {
                 if (defaultStream < 0 && streams[i]->is_default)
                     defaultStream = i;
                 if (!lang.isEmpty() && chosenLangStream < 0)
                 {
-                    for (const QMPlay2Tag &tag : asConst(streams[i]->other_info))
+                    for (const QMPlay2Tag &tag : qAsConst(streams[i]->other_info))
                     {
                         if (tag.first.toInt() == QMPLAY2_TAG_LANGUAGE)
                         {
@@ -1312,7 +1295,7 @@ static Decoder *loadStream(
         for (int i = 0; i < streams.count(); ++i)
         {
             StreamInfo &streamInfo = *streams[i];
-            if (streamInfo.codec_type == type && (defaultStream == -1 || i == defaultStream))
+            if (streamInfo.params->codec_type == type && (defaultStream == -1 || i == defaultStream))
             {
                 if (streamInfo.must_decode || !subtitles)
                     dec = Decoder::create(streamInfo, decoders, modNameOutput);
@@ -1383,13 +1366,14 @@ void PlayClass::load(Demuxer *demuxer)
 
                 vThr->setDec(dec);
 
-                vThr->setFrameSize(streams[videoStream]->width, streams[videoStream]->height);
+                vThr->setFrameSize(streams[videoStream]->params->width, streams[videoStream]->params->height);
                 vThr->setARatio(aspect_ratio, getSAR());
                 vThr->setVideoAdjustment();
                 vThr->setZoom();
                 const bool hasSpherical = vThr->setSpherical();
                 const bool hasRotate90 = vThr->setRotate90();
                 vThr->setFlip();
+                vThr->setColorInfo(streams[videoStream]->params->color_primaries, streams[videoStream]->params->color_trc);
                 vThr->initFilters();
 
                 bool mustEmitSetVideoCheckState = false;
@@ -1420,16 +1404,7 @@ void PlayClass::load(Demuxer *demuxer)
                     ass->setFontScale(subtitlesScale);
                     ass->setARatio(aspect_ratio);
                     ass->setZoom(zoom);
-
-#if defined Q_OS_WIN && !defined Q_OS_WIN64
-                    if (LibASS::slowFontCacheUpdate() && firsttimeUpdateCache)
-                    {
-                        UpdateFC updateFC(ass);
-                        firsttimeUpdateCache = false;
-                    }
-                    else
-#endif
-                        ass->initOSD();
+                    ass->initOSD();
 
                     emit videoStarted(noVideo);
 
@@ -1474,7 +1449,7 @@ void PlayClass::load(Demuxer *demuxer)
             {
                 aThr->setDec(dec);
 
-                if (!setAudioParams(streams[audioStream]->channels, streams[audioStream]->sample_rate))
+                if (!setAudioParams(streams[audioStream]->params->CODECPAR_NB_CHANNELS, streams[audioStream]->params->sample_rate))
                     dec = nullptr;
 
                 else if (reload)
@@ -1514,7 +1489,6 @@ void PlayClass::load(Demuxer *demuxer)
             subsMutex.lock();
             vThr->destroySubtitlesDecoder();
             ass->closeASS();
-            ass->clearFonts();
             subsMutex.unlock();
 
             if (subtitlesEnabled && fileSubsList.count() && chosenSubtitlesStream < 0)
@@ -1536,17 +1510,24 @@ void PlayClass::load(Demuxer *demuxer)
                         subtitlesSync = 0.0;
                     subsMutex.lock();
                     if (dec)
-                        vThr->setSubtitlesDecoder(dec);
-                    QByteArray assHeader = streams[subtitlesStream]->getExtraData();
-                    if (!assHeader.isEmpty() && (streams[subtitlesStream]->codec_name == "ssa" || streams[subtitlesStream]->codec_name == "ass"))
                     {
-                        loadAssFonts(streams);
+                        vThr->setSubtitlesDecoder(dec, streams[subtitlesStream]->decode_to_ass);
+                        if (streams[subtitlesStream]->decode_to_ass)
+                            ass->initASS(dec->subtitleHeader());
                     }
                     else
                     {
-                        assHeader.clear();
+                        QByteArray assHeader = streams[subtitlesStream]->getExtraData();
+                        if (!assHeader.isEmpty() && (streams[subtitlesStream]->codec_name == "ssa" || streams[subtitlesStream]->codec_name == "ass"))
+                        {
+                            loadAssFonts(streams);
+                        }
+                        else
+                        {
+                            assHeader.clear();
+                        }
+                        ass->initASS(assHeader);
                     }
-                    ass->initASS(assHeader);
                     if (reload)
                     {
                         seekTo = SEEK_STREAM_RELOAD;
