@@ -65,6 +65,8 @@ Radio::Radio(Module &module) :
 
     m_loadIconsTimer->setInterval(10);
 
+    m_net->setRetries(g_nRetries, g_retryInterval);
+
     ui->setupUi(this);
 
     ui->addMyRadioStationButton->setIcon(QMPlay2Core.getIconFromTheme("list-add"));
@@ -97,6 +99,7 @@ Radio::Radio(Module &module) :
     connect(m_dw, SIGNAL(visibilityChanged(bool)), this, SLOT(visibilityChanged(bool)));
     connect(m_radioBrowserModel, SIGNAL(radiosAdded()), m_loadIconsTimer, SLOT(start()));
     connect(m_radioBrowserModel, SIGNAL(searchFinished()), this, SLOT(searchFinished()));
+    connect(m_radioBrowserModel, &RadioBrowserModel::connectionError, this, &Radio::connectionError);
     connect(ui->radioView->verticalScrollBar(), SIGNAL(valueChanged(int)), m_loadIconsTimer, SLOT(start()));
     connect(m_loadIconsTimer, SIGNAL(timeout()), this, SLOT(loadIcons()));
     connect(ui->filterEdit, SIGNAL(textEdited(QString)), m_radioBrowserModel, SLOT(setFiltrText(QString)));
@@ -248,10 +251,18 @@ void Radio::loadIcons()
 
 void Radio::replyFinished(NetworkReply *reply)
 {
-    if (!reply->hasError())
+    const int idx = m_searchInfo.key({{}, reply}, -1);
+    if (idx > -1)
     {
-        const int idx = m_searchInfo.key({{}, reply}, -1);
-        if (idx > -1)
+        if (reply->hasError())
+        {
+            if (!m_errorDisplayed)
+            {
+                connectionError();
+                m_errorDisplayed = true;
+            }
+        }
+        else
         {
             const QJsonDocument json = QJsonDocument::fromJson(reply->readAll());
             if (json.isArray())
@@ -490,8 +501,7 @@ void Radio::radioBrowserPlayOrEnqueue(const QModelIndex &index, const QString &p
     const QString uuid = m_radioBrowserModel->getUUID(index);
 
     // Increase clickcount
-    auto reply = m_net->start(QString("%1/url/%2").arg(g_radioBrowserBaseApiUrl, uuid));
-    connect(reply, &NetworkReply::finished, reply, &NetworkReply::deleteLater);
+    m_net->start(QString("%1/url/%2").arg(g_radioBrowserBaseApiUrl, uuid));
 
     QMPlay2Core.addNameForUrl(url, title);
     emit QMPlay2Core.processParam(param, url);
@@ -629,6 +639,11 @@ void Radio::play(const QString &url, const QString &name)
     emit QMPlay2Core.processParam("open", url);
 }
 
+void Radio::connectionError()
+{
+    emit QMPlay2Core.sendMessage(tr("Connection error"), RadioName, 3);
+}
+
 bool Radio::eventFilter(QObject *watched, QEvent *event)
 {
     if (watched == ui->myRadioListWidget)
