@@ -702,8 +702,12 @@ void Frame::copyAVFrameInfo(const AVFrame *other)
     m_frame->format = other->format;
     m_frame->width = other->width;
     m_frame->height = other->height;
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(57, 28, 100)
+    m_frame->ch_layout = other->ch_layout;
+#else
     m_frame->channels = other->channels;
     m_frame->channel_layout = other->channel_layout;
+#endif
     m_frame->nb_samples = other->nb_samples;
 
     av_frame_copy_props(m_frame, other);
